DisconnectCode

Enum DisconnectCode 

pub enum DisconnectCode {
    Shutdown = 1,
    DuplicateStream = 2,
    ControlRequest = 3,
    Stall = 4,
    Normal = 5,
    TokenRevoked = 6,
    AdminLogout = 7,
    MaxMessageLimit = 9,
    StreamException = 10,
    BrokerStall = 11,
    ShedLoad = 12,
}
Status code for a Disconnect message.

Variants



Shutdown = 1

The feed was shutdown (possibly a machine restart).



DuplicateStream = 2

The same endpoint was connected too many times.



ControlRequest = 3

Control streams was used to close a stream (applies to sitestreams).



Stall = 4

The client was reading too slowly and was disconnected by the server.



Normal = 5

The client appeared to have initiated a disconnect.



TokenRevoked = 6

An oauth token was revoked for a user (applies to site and userstreams).



AdminLogout = 7

The same credentials were used to connect a new stream and the oldest was disconnected.



MaxMessageLimit = 9

The stream connected with a negative count parameter and was disconnected after all backfill was delivered.



StreamException = 10

An internal issue disconnected the stream.



BrokerStall = 11

An internal issue disconnected the stream.



ShedLoad = 12

The host the stream was connected to became overloaded and streams were disconnected to balance load. Reconnect as usual.