EventKind

Enum EventKind 

pub enum EventKind<'a> {
Show 17 variants Favorite(Box<Tweet<'a>>), Unfavorite(Box<Tweet<'a>>), ListCreated(Box<List<'a>>), ListDestroyed(Box<List<'a>>), ListUpdated(Box<List<'a>>), ListMemberAdded(Box<List<'a>>), ListMemberRemoved(Box<List<'a>>), ListUserSubscribed(Box<List<'a>>), ListUserUnsubscribed(Box<List<'a>>), QuotedTweet(Box<Tweet<'a>>), AccessRevoked, Block, Unblock, Follow, Unfollow, UserUpdate, Custom(Cow<'a, str>, Option<JsonValue>),
}
An object which indicates the name of an event. It may contain an object called “target object” which represents the target of the event.

The meaning of target and source field of an Event will be different based on the name of the event, as described below.

DescriptionEvent Namesourcetarget
User deauthorizes streamAccessRevokedDeauthorizing userApp owner
User blocks someoneBlockCurrent userBlocked user
User removes a blockUnblockCurrent userUnblocked user
User favorites a TweetFavoriteCurrent userTweet author
User’s Tweet is favoritedFavoriteFavoriting userCurrent user
User unfavorites a TweetUnfavoriteCurrent userTweet author
User’s Tweet is unfavoritedUnfavoriteUnfavoriting userCurrent user
User follows someoneFollowCurrent userFollowed user
User is followedFollowFollowing userCurrent user
User unfollows someoneUnfollowCurrent userFollowed user
User creates a listListCreatedCurrent userCurrent user
User deletes a listListDestroyedCurrent userCurrent user
User edits a listListUpdatedCurrent userCurrent user
User adds someone to a listListMemberAddedCurrent userAdded user
User is added to a listListMemberAddedAdding userCurrent user
User removes someone from a listListMemberRemovedCurrent userRemoved user
User is removed from a listListMemberRemovedRemoving userCurrent user
User subscribes to a listListUserSubscribedCurrent userList owner
User’s list is subscribed toListUserSubscribedSubscribing userCurrent user
User unsubscribes from a listListUserUnsubscribedCurrent userList owner
User’s list is unsubscribed fromListUserUnsubscribedUnsubscribing userCurrent user
User’s Tweet is quotedQuotedTweetquoting UserCurrent User
User updates their profileUserUpdateCurrent userCurrent user
User updates their protected statusUserUpdateCurrent userCurrent user

Variants



Favorite(Box<Tweet<'a>>)



Unfavorite(Box<Tweet<'a>>)



ListCreated(Box<List<'a>>)



ListDestroyed(Box<List<'a>>)



ListUpdated(Box<List<'a>>)



ListMemberAdded(Box<List<'a>>)



ListMemberRemoved(Box<List<'a>>)



ListUserSubscribed(Box<List<'a>>)



ListUserUnsubscribed(Box<List<'a>>)



QuotedTweet(Box<Tweet<'a>>)



AccessRevoked



Block



Unblock



Follow



Unfollow



UserUpdate



Custom(Cow<'a, str>, Option<JsonValue>)

An event this library does not know. The first value is raw event name and the second is the target object.